﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.Storage.Pickers;
using Windows.Storage;
using Windows.UI.Xaml.Media.Imaging;
using Windows.Storage.Streams;
using ViscomsoftOCR;
using Windows.UI.Popups;
// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace App1
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private StorageFile _imageFile;
        public MainPage()
        {
            this.InitializeComponent();
        }

        private async void uiOpen_Click(object sender, RoutedEventArgs e)
        {
            FileOpenPicker openPicker = new FileOpenPicker();
            openPicker.ViewMode = PickerViewMode.Thumbnail;
            openPicker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            openPicker.FileTypeFilter.Add(".jpg");
            openPicker.FileTypeFilter.Add(".jpeg");
            openPicker.FileTypeFilter.Add(".png");
            openPicker.FileTypeFilter.Add(".gif");
            openPicker.FileTypeFilter.Add(".tif");

            _imageFile = await openPicker.PickSingleFileAsync();

            if (_imageFile == null)
                return;

            BitmapImage bitmapImage = new BitmapImage();
            IRandomAccessStream stream = await _imageFile.OpenReadAsync();
            await bitmapImage.SetSourceAsync(stream);

            uiInputImage.Source = bitmapImage;

        }

        private async void uiStart_Click(object sender, RoutedEventArgs e)
        {
            if (_imageFile == null)
                return;

            try
            {
                IRandomAccessStream stream = await _imageFile.OpenReadAsync();

                ViscomsoftOcr ocr = new ViscomsoftOcr();

                StorageFolder tessdataFolderobj = await Windows.ApplicationModel.Package.Current.InstalledLocation.GetFolderAsync("tessdata");

                 Language lang = ViscomsoftOCR.Language.English;
                 bool result;

                result = await ocr.initAsync(lang, tessdataFolderobj.Path);

                MessageDialog dlgError =null; 
                if (!result)
                {

                    dlgError = new MessageDialog("ERROR!!! - Language data not found");
                    dlgError.ShowAsync();
                    return;
                }

                ocr.setImage(stream);

                result = await ocr.recognizeAsync();

                if (!result)
                {
                    dlgError = new MessageDialog("ERROR!!! - recognize error");
                    dlgError.ShowAsync();
                    return;

                }

                MessageDialog dlg = new MessageDialog(await ocr.getUTF8TextAsync());
                dlg.ShowAsync();

            }
            catch (Exception ex)
            {
                MessageDialog dlg = new MessageDialog("ERROR!!! - " + ex.Message);
                dlg.ShowAsync();
               
            }
        }

    }
}
